@@ -387,7 +387,7 @@ class ServiceCLI(DockerCLICaller):
 
         # Raises
             `python_on_whales.exceptions.NoSuchService` if one of the services
-            doesn't exists.
+            doesn't exist.
         """
         full_cmd = (
             self.docker_cmd + ["service", "ps", "--quiet", "--no-trunc"] + to_list(x)
@@ -408,10 +408,13 @@ class ServiceCLI(DockerCLICaller):
 
         # Raises
             `python_on_whales.exceptions.NoSuchService` if one of the services
-            doesn't exists.
+            doesn't exist.
         """
         full_cmd = self.docker_cmd + ["service", "remove"]
 
+        if services == []:
+            return
+
         for service in to_list(services):
             full_cmd.append(service)
 
